
<h2 align="center">Oxia Client SDK for Python</h1>
a robust, scalable metadata store and coordination system designed for large-scale distributed systems, with built-in support for stream index storage to optimize real-time data management.

<p align="center">
  <a href="https://oxia-db.github.io/docs/getting-started">Getting Started </a> | <a href="https://oxia-db.github.io/">Documentation</a>
</p>

<p align="center">
  <a href="https://github.com/oxia-db/oxia-client-python/releases"><img src="https://img.shields.io/github/v/release/oxia-db/oxia" alt="Latest Release"></a>
  <a href="https://github.com/oxia-db/oxia-client-python/actions/workflows/run-tests.yaml/badge.svg"><img src="https://github.com/oxia-db/oxia-client-python/actions/workflows/run-tests.yaml/badge.svg" alt="CI"></a>
  <a href="https://github.com/oxia-db/oxia-client-python/blob/main/LICENSE"><img src="https://img.shields.io/badge/license-Apache%202.0-white.svg" alt="License"></a>
  <a href="https://github.com/oxia-db/oxia-client-python/discussions/new/choose"><img src="https://img.shields.io/badge/Github-Discussion-blue.svg?logo=refinedgithub" alt="Github Discussion"></a>
</p>

<br><br><br>

### Contributing to Oxia

Please 🌟 star the project if you like it. 

Feel free to open an [issue](https://github.com/oxia-db/oxia-client-python/issues/new) or start a [discussion](https://github.com/oxia-db/oxia/discussions/new/choose). You can also follow the development [guide]() to contribute and build on it.

### License

Copyright 2025 StreamNative, Inc.

Licensed under the Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0